```{include} ../README.md
---
end-before: <!-- github-only -->
---
```

[license]: license
[contributor guide]: contributing
[command-line reference]: usage

```{toctree}
---
hidden:
maxdepth: 2
---

reference
contributing
Code of Conduct <codeofconduct>
License <license>
Changelog <https://github.com/dgarnier/inductance/releases>
```
